@@ -3,6 +3,8 @@ from django.http import Http404
 
 from djangodblog.models import Error
 
+import sys
+
 __all__ = ('DBLogMiddleware',)
 
 class DBLogMiddleware(object):
@@ -10,7 +12,10 @@ class DBLogMiddleware(object):
         if not getattr(settings, 'DBLOG_CATCH_404_ERRORS', False) and isinstance(exception, Http404):
             return
 
-        Error.objects.create_from_exception(exception, url=request.build_absolute_uri(), data=dict(
+        if getattr(exception, 'skip_dblog', False):
+            return
+
+        Error.objects.create_from_exception(url=request.build_absolute_uri(), data=dict(
             META=request.META,
             POST=request.POST,
             GET=request.GET,
